import { IgxCalendarBaseDirective } from './calendar-base';
import { ElementRef, QueryList } from '@angular/core';
import * as i0 from "@angular/core";
export declare const IgxCalendarView: {
    Month: "month";
    Year: "year";
    Decade: "decade";
};
/**
 * @hidden
 */
export declare enum CalendarView {
    DEFAULT = 0,
    YEAR = 1,
    DECADE = 2
}
/**
 * Determines the Calendar active view - days, months or years.
 */
export declare type IgxCalendarView = (typeof IgxCalendarView)[keyof typeof IgxCalendarView] | CalendarView;
export declare class IgxMonthPickerBaseDirective extends IgxCalendarBaseDirective {
    /**
     * @hidden
     */
    yearsBtns: QueryList<ElementRef>;
    /**
     * @hidden @internal
     */
    previousViewDate: Date;
    /**
     * Holds month view index we are operating on.
     */
    protected activeViewIdx: number;
    /**
     * @hidden
     */
    private _activeView;
    /**
     * Gets the current active view.
     * ```typescript
     * this.activeView = calendar.activeView;
     * ```
     */
    get activeView(): IgxCalendarView;
    /**
     * Sets the current active view.
     * ```html
     * <igx-calendar [activeView]="year" #calendar></igx-calendar>
     * ```
     * ```typescript
     * calendar.activeView = IgxCalendarView.YEAR;
     * ```
     */
    set activeView(val: IgxCalendarView);
    /**
     * @hidden
     */
    get isDefaultView(): boolean;
    /**
     * @hidden
     */
    get isDecadeView(): boolean;
    /**
     * @hidden
     */
    changeYear(event: Date): void;
    /**
     * @hidden
     */
    activeViewDecade(activeViewIdx?: number): void;
    /**
     * @hidden
     */
    activeViewDecadeKB(event: KeyboardEvent, activeViewIdx?: number): void;
    /**
     * Returns the locale representation of the year in the year view if enabled,
     * otherwise returns the default `Date.getFullYear()` value.
     *
     * @hidden
     */
    formattedYear(value: Date): string;
    static ɵfac: i0.ɵɵFactoryDeclaration<IgxMonthPickerBaseDirective, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<IgxMonthPickerBaseDirective, "[igxMonthPickerBase]", never, { "activeView": "activeView"; }, {}, never, never, false, never>;
}
