import { IGridResourceStrings } from '../../core/i18n/grid-resources';
import { GridColumnDataType } from '../../data-operations/data-util';
import { IPivotDimension } from './pivot-grid.interface';
export interface IPivotDateDimensionOptions {
    /** Enables/Disables total value of all periods. */
    total?: boolean;
    /** Enables/Disables dimensions per year from provided periods. */
    years?: boolean;
    quarters?: boolean;
    /** Enables/Disables dimensions per month from provided periods. */
    months?: boolean;
    /** Enabled/Disables dimensions for the full date provided */
    fullDate?: boolean;
}
export declare class IgxPivotDateDimension implements IPivotDimension {
    inBaseDimension: IPivotDimension;
    inOptions: IPivotDateDimensionOptions;
    /** Enables/Disables a particular dimension from pivot structure. */
    enabled: boolean;
    /**
     * Gets/Sets data type
     */
    dataType?: GridColumnDataType;
    /** Default options used for initialization. */
    defaultOptions: {
        total: boolean;
        years: boolean;
        months: boolean;
        fullDate: boolean;
    };
    /**
     * Gets/Sets the resource strings.
     *
     * @remarks
     * By default it uses EN resources.
     */
    set resourceStrings(value: IGridResourceStrings);
    get resourceStrings(): IGridResourceStrings;
    /** @hidden @internal */
    childLevel?: IPivotDimension;
    /** @hidden @internal */
    memberName: string;
    private _resourceStrings;
    private _monthIntl;
    /**
     * Creates additional pivot date dimensions based on a provided dimension describing date data:
     *
     * @param inDateDimension Base dimension that is used by this class to determine the other dimensions and their values.
     * @param inOptions Options for the predefined date dimensions whether to show quarter, years and etc.
     * @example
     * ```typescript
     * // Displays only years as parent dimension to the base dimension provided.
     * new IgxPivotDateDimension({ memberName: 'Date', enabled: true }, { total: false, months: false });
     * ```
     */
    constructor(inBaseDimension: IPivotDimension, inOptions?: IPivotDateDimensionOptions);
    /** @hidden @internal */
    memberFunction: (_data: any) => string;
}
